[Libreoffice-commits] .: 4 commits - bean/native jvmfwk/plugins

David Tardon dtardon at kemper.freedesktop.org
Wed Apr 18 12:01:54 PDT 2012


 bean/native/win32/com_sun_star_comp_beans_LocalOfficeWindow.c |    2 -
 jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.cxx           |   16 +++++-----
 jvmfwk/plugins/sunmajor/pluginlib/sunjre.cxx                  |    8 ++---
 3 files changed, 13 insertions(+), 13 deletions(-)

New commits:
commit c6ade7266f5d1d16e4dc9a002ecde6bdf449dbfd
Author: David Tardon <dtardon at redhat.com>
Date:   Wed Apr 18 13:07:03 2012 +0200

    WaE: cast from pointer to integer of different size

diff --git a/bean/native/win32/com_sun_star_comp_beans_LocalOfficeWindow.c b/bean/native/win32/com_sun_star_comp_beans_LocalOfficeWindow.c
index 7ad1126..bd8b37e 100644
--- a/bean/native/win32/com_sun_star_comp_beans_LocalOfficeWindow.c
+++ b/bean/native/win32/com_sun_star_comp_beans_LocalOfficeWindow.c
@@ -166,7 +166,7 @@ JNIEXPORT jlong JNICALL Java_com_sun_star_comp_beans_LocalOfficeWindow_getNative
         SetProp( hWnd, OLD_PROC_KEY, (HANDLE)hFuncPtr );
     }
 
-    return ((jlong)hWnd);
+    return ((jlong)(LONG)hWnd);
 }
 
 
commit 2ff039195f817f3c372b4ba3bf59539948ce213d
Author: David Tardon <dtardon at redhat.com>
Date:   Tue Apr 17 07:17:45 2012 +0200

    use SAL_N_ELEMENTS

diff --git a/jvmfwk/plugins/sunmajor/pluginlib/sunjre.cxx b/jvmfwk/plugins/sunmajor/pluginlib/sunjre.cxx
index 1ba0279..1ffa982 100644
--- a/jvmfwk/plugins/sunmajor/pluginlib/sunjre.cxx
+++ b/jvmfwk/plugins/sunmajor/pluginlib/sunjre.cxx
@@ -59,7 +59,7 @@ char const* const* SunInfo::getJavaExePaths(int * size)
         "jre/bin/java"
 #endif
     };
-        *size = sizeof (ar) / sizeof (char*);
+        *size = SAL_N_ELEMENTS(ar);
     return ar;
 }
 
@@ -79,7 +79,7 @@ char const* const* SunInfo::getRuntimePaths(int * size)
 #endif
 
     };
-    *size = sizeof(ar) / sizeof (char*);
+    *size = SAL_N_ELEMENTS(ar);
     return ar;
 }
 
@@ -94,7 +94,7 @@ char const* const* SunInfo::getLibraryPaths(int* size)
         "/lib/" JFW_PLUGIN_ARCH
 
     };
-    *size = sizeof(ar) / sizeof (char*);
+    *size = SAL_N_ELEMENTS(ar);
     return ar;
 #else
     *size = 0;
commit ea68b1a8977becd8f827d41b171e89d3b490216e
Author: David Tardon <dtardon at redhat.com>
Date:   Tue Apr 17 07:15:44 2012 +0200

    WaE: parameter 'size' set but not used

diff --git a/jvmfwk/plugins/sunmajor/pluginlib/sunjre.cxx b/jvmfwk/plugins/sunmajor/pluginlib/sunjre.cxx
index 52bd451..1ba0279 100644
--- a/jvmfwk/plugins/sunmajor/pluginlib/sunjre.cxx
+++ b/jvmfwk/plugins/sunmajor/pluginlib/sunjre.cxx
@@ -97,7 +97,7 @@ char const* const* SunInfo::getLibraryPaths(int* size)
     *size = sizeof(ar) / sizeof (char*);
     return ar;
 #else
-    size = 0;
+    *size = 0;
     return NULL;
 #endif
 }
commit ec4f5494dae3bd9819f07fe3ada6310a8bef468d
Author: David Tardon <dtardon at redhat.com>
Date:   Tue Apr 17 07:11:13 2012 +0200

    WaE: declaration of 'errcode' shadows a global declaration

diff --git a/jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.cxx b/jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.cxx
index a4b9a1d..ffa6b55 100644
--- a/jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.cxx
+++ b/jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.cxx
@@ -347,7 +347,7 @@ javaPluginError jfw_plugin_getJavaInfoByPath(
     sal_Int32  nLenList,
     JavaInfo ** ppInfo)
 {
-    javaPluginError errcode = JFW_PLUGIN_E_NONE;
+    javaPluginError errorcode = JFW_PLUGIN_E_NONE;
 
     OSL_ASSERT(path);
     OSL_ASSERT(sVendor);
@@ -444,7 +444,7 @@ javaPluginError jfw_plugin_getJavaInfoByPath(
     }
     *ppInfo = createJavaInfo(aVendorInfo);
 
-    return errcode;
+    return errorcode;
 }
 
 #if defined(WNT)
@@ -571,9 +571,9 @@ javaPluginError jfw_plugin_startJavaVirtualMachine(
     // unless guard is volatile the following warning occurs on gcc:
     // warning: variable 't' might be clobbered by `longjmp' or `vfork'
     volatile osl::MutexGuard guard(PluginMutex::get());
-    // unless errcode is volatile the following warning occurs on gcc:
-    // warning: variable 'errcode' might be clobbered by `longjmp' or `vfork'
-    volatile javaPluginError errcode = JFW_PLUGIN_E_NONE;
+    // unless errorcode is volatile the following warning occurs on gcc:
+    // warning: variable 'errorcode' might be clobbered by `longjmp' or `vfork'
+    volatile javaPluginError errorcode = JFW_PLUGIN_E_NONE;
     if ( pInfo == NULL || ppVm == NULL || ppEnv == NULL)
         return JFW_PLUGIN_E_INVALID_ARG;
     //Check if the Vendor (pInfo->sVendor) is supported by this plugin
@@ -737,13 +737,13 @@ javaPluginError jfw_plugin_startJavaVirtualMachine(
         {
             fprintf(stderr,"[Java framework] sunjavaplugin" SAL_DLLEXTENSION
                     "Can not create Java Virtual Machine\n");
-            errcode = JFW_PLUGIN_E_VM_CREATION_FAILED;
+            errorcode = JFW_PLUGIN_E_VM_CREATION_FAILED;
         }
         else if( err > 0)
         {
             fprintf(stderr,"[Java framework] sunjavaplugin" SAL_DLLEXTENSION
                     "Can not create JavaVirtualMachine, abort handler was called.\n");
-            errcode = JFW_PLUGIN_E_VM_CREATION_FAILED;
+            errorcode = JFW_PLUGIN_E_VM_CREATION_FAILED;
         }
     }
     else
@@ -760,7 +760,7 @@ javaPluginError jfw_plugin_startJavaVirtualMachine(
     fprintf(stderr, "lo_get_javavm returns %p", *ppVm);
 #endif
 
-   return errcode;
+   return errorcode;
 }
 
 extern "C"


More information about the Libreoffice-commits mailing list